<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up()
    {
        Schema::table('user_auths', function (Blueprint $table) {
            $table->text('outlook_access_token')->nullable();
            $table->text('outlook_refresh_token')->nullable();
            $table->timestamp('outlook_token_expiry')->nullable();
        });
    }
    
    public function down()
    {
        Schema::table('user_auths', function (Blueprint $table) {
            $table->dropColumn(['outlook_access_token', 'outlook_refresh_token', 'outlook_token_expiry']);
        });
    }
    
};
