<?php

namespace Database\Factories;

use App\Models\Appreciation;
use Illuminate\Database\Eloquent\Factories\Factory;

class AppreciationFactory extends Factory
{
    /**
     * The name of the factory's corresponding model.
     *
     * @var string
     */
    protected $model = Appreciation::class;

    /**
     * Define the model's default state.
     *
     * @return array
     */
    public function definition()
    {

        return [
            'summary' => fake()->realText(),
        ];
    }

}
