<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::table('letter_templates', function (Blueprint $table) {
            $table->unsignedInteger('project_category_id')->nullable()->after('id');
            $table->foreign('project_category_id')
                  ->references('id')
                  ->on('project_category')
                  ->onDelete('set null');
        });
        
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('letter_template', function (Blueprint $table) {
            //
        });
    }
};
